@@ -5,4 +5,4 @@ def writeConfig():
     password = input("Password for the mailserver: ")
 
     with open("mailConfig.py", "w") as f:
-        f.write(f'cfgmail = {{\n"username" : {username},\n"password" : {password},\n"server" : {server},\n"port" : {port}\n}}')
\ No newline at end of file
+        f.write(f'cfgmail = {{\n"username" : "{username}",\n"password" : "{password}",\n"server" : "{server}",\n"port" : {port}\n}}')
\ No newline at end of file
